@@ -1,13 +1,14 @@
 import unittest
 import quickbe
+from quickbeserverless import is_valid_http_handler
 
 
 def demo_1(session: quickbe.HttpSession):
-    return session.get_parameter('text')
+    return session.get('text')
 
 
 def demo_2(session: quickbe.HttpSession, s: str):
-    return session.get_parameter('text')
+    return session.get('text')
 
 
 def demo_3(session: str):
@@ -18,13 +19,13 @@ class WebServerTestCase(unittest.TestCase):
 
     def test_http_handler(self):
 
-        self.assertEqual(True, quickbe._is_valid_http_handler(func=demo_1))
+        self.assertEqual(True, is_valid_http_handler(func=demo_1))
 
         with self.assertRaises(TypeError):
-            self.assertEqual(True, quickbe._is_valid_http_handler(func=demo_2))
+            self.assertEqual(True, is_valid_http_handler(func=demo_2))
 
         with self.assertRaises(TypeError):
-            self.assertEqual(True, quickbe._is_valid_http_handler(func=demo_3))
+            self.assertEqual(True, is_valid_http_handler(func=demo_3))
 
 
 if __name__ == '__main__':
